@@ -1,6 +1,9 @@
 # ABSTRACT: Constants used by PONAPI::DAO and PONAPI repositories
 package PONAPI::Constants;
 
+use strict;
+use warnings;
+
 my $constants;
 BEGIN {
     $constants = {
@@ -38,7 +41,7 @@ PONAPI::Constants - Constants used by PONAPI::DAO and PONAPI repositories
 
 =head1 VERSION
 
-version 0.002005
+version 0.002006
 
 =head1 SYNOPSIS
 
