@@ -33,7 +33,7 @@ PONAPI::Repository - Interface role for PONAPI::DAO repositories
 
 =head1 VERSION
 
-version 0.002005
+version 0.002006
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ version 0.002005
         ...
     }
 
-=HEAD1 DESCRIPTION
+=head1 DESCRIPTION
 
 Clases implementing repositories for L<PONAPI::DAO> must consume
 the C<PONAPI::Repository> role; this ensures that the methods
@@ -58,7 +58,7 @@ with the exceptions of the C<has_*> methods, B<all> methods
 will receive a C<document> argument, which is always an instance of
 C<PONAPI::Builder::Document>, but not necessarily a B<new> instance.
 
-=HEAD1 REQUIRES
+=head1 REQUIRES
 
 =head2 $obj->has_type( $type )
 
