@@ -1,7 +1,10 @@
 # ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
 package PONAPI::Server;
 
-our $VERSION = '0.002005';
+use strict;
+use warnings;
+
+our $VERSION = '0.002006';
 
 use Plack::Request;
 use Plack::Response;
@@ -9,6 +12,7 @@ use HTTP::Headers::ActionPack;
 use Module::Runtime    ();
 use Return::MultiLevel ();
 use JSON::XS           ();
+use URI::Escape        qw( uri_unescape );
 
 use PONAPI::Server::ConfigReader;
 use PONAPI::Utils::Names qw( check_name );
@@ -190,6 +194,8 @@ sub _ponapi_query_params {
     my %params;
     my $query_params = $req->query_parameters;
 
+    my $unesacpe_values = !!$req->headers->header('X-PONAPI-Escaped-Values');
+
     # loop over query parameters (unique keys)
     for my $k ( keys %{ $query_params } ) {
         my ( $p, $f ) = $k =~ /^ (\w+?) (?:\[(\w+)\])? $/x;
@@ -207,7 +213,8 @@ sub _ponapi_query_params {
             if $p eq 'sort' and !$self->{'ponapi.sort_allowed'};
 
         # values can be passed as CSV
-        my @values = map { split /,/ } $query_params->get_all($k);
+        my @values = map { $unesacpe_values ? uri_unescape($_) : $_ }
+                     map { split /,/ } $query_params->get_all($k);
 
         # check we have values for a given key
         # (for 'fields' an empty list is valid)
@@ -257,7 +264,7 @@ sub _ponapi_data {
 sub _validate_data_members {
     my ( $self, $wr, $data ) = @_;
 
-    @recs = ref $data eq 'ARRAY' ? @{$data} : $data;
+    my @recs = ref $data eq 'ARRAY' ? @{$data} : $data;
 
     for my $r ( @recs ) {
         return unless keys %{$r};
@@ -333,7 +340,7 @@ PONAPI::Server - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/
 
 =head1 VERSION
 
-version 0.002005
+version 0.002006
 
 =head1 SYNOPSIS
 
